@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2013 Laurent Gomila (laurent.gom@gmail.com)
+// Copyright (C) 2007-2015 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -36,6 +36,7 @@
 #include <SFML/Graphics/RectangleShapeStruct.h>
 #include <SFML/Graphics/VertexArrayStruct.h>
 #include <SFML/Graphics/ConvertRenderStates.hpp>
+#include <SFML/Window/Touch.hpp>
 #include <SFML/Internal.h>
 #include <SFML/ConvertEvent.h>
 
@@ -55,6 +56,7 @@ sfRenderWindow* sfRenderWindow_create(sfVideoMode mode, const char* title, sfUin
         params.antialiasingLevel = settings->antialiasingLevel;
         params.majorVersion      = settings->majorVersion;
         params.minorVersion      = settings->minorVersion;
+        params.attributeFlags    = settings->attributeFlags;
     }
 
     // Create the window
@@ -81,6 +83,7 @@ sfRenderWindow* sfRenderWindow_createUnicode(sfVideoMode mode, const sfUint32* t
         params.antialiasingLevel = settings->antialiasingLevel;
         params.majorVersion      = settings->majorVersion;
         params.minorVersion      = settings->minorVersion;
+        params.attributeFlags    = settings->attributeFlags;
     }
 
     // Create the window
@@ -105,6 +108,7 @@ sfRenderWindow* sfRenderWindow_createFromHandle(sfWindowHandle handle, const sfC
         params.antialiasingLevel = settings->antialiasingLevel;
         params.majorVersion      = settings->majorVersion;
         params.minorVersion      = settings->minorVersion;
+        params.attributeFlags    = settings->attributeFlags;
     }
 
     // Create the window
@@ -150,6 +154,7 @@ sfContextSettings sfRenderWindow_getSettings(const sfRenderWindow* renderWindow)
     settings.antialiasingLevel = params.antialiasingLevel;
     settings.majorVersion      = params.majorVersion;
     settings.minorVersion      = params.minorVersion;
+    settings.attributeFlags    = params.attributeFlags;
 
     return settings;
 }
@@ -295,6 +300,20 @@ sfBool sfRenderWindow_setActive(sfRenderWindow* renderWindow, sfBool active)
 }
 
 
+////////////////////////////////////////////////////////////
+void sfRenderWindow_requestFocus(sfRenderWindow* renderWindow)
+{
+    CSFML_CALL(renderWindow, requestFocus());
+}
+
+
+////////////////////////////////////////////////////////////
+sfBool sfRenderWindow_hasFocus(const sfRenderWindow* renderWindow)
+{
+    CSFML_CALL_RETURN(renderWindow, hasFocus(), sfFalse);
+}
+
+
 ////////////////////////////////////////////////////////////
 void sfRenderWindow_display(sfRenderWindow* renderWindow)
 {
@@ -456,7 +475,7 @@ void sfRenderWindow_drawVertexArray(sfRenderWindow* renderWindow, const sfVertex
 
 ////////////////////////////////////////////////////////////
 void sfRenderWindow_drawPrimitives(sfRenderWindow* renderWindow,
-                                   const sfVertex* vertices, unsigned int vertexCount,
+                                   const sfVertex* vertices, size_t vertexCount,
                                    sfPrimitiveType type, const sfRenderStates* states)
 {
     CSFML_CALL(renderWindow, draw(reinterpret_cast<const sf::Vertex*>(vertices), vertexCount,
@@ -519,3 +538,17 @@ void sfMouse_setPositionRenderWindow(sfVector2i position, const sfRenderWindow*
     else
         sf::Mouse::setPosition(sf::Vector2i(position.x, position.y));
 }
+
+////////////////////////////////////////////////////////////
+sfVector2i sfTouch_getPositionRenderWindow(unsigned int finger, const sfRenderWindow* relativeTo)
+{
+    sf::Vector2i sfmlPosition;
+
+    if (relativeTo)
+        sfmlPosition = sf::Touch::getPosition(finger, relativeTo->This);
+    else
+        sfmlPosition = sf::Touch::getPosition(finger);
+
+    sfVector2i position = { sfmlPosition.x, sfmlPosition.y };
+    return position;
+}
